@@ -267,7 +267,7 @@ html_read_row (htmlNodePtr cur, htmlDocPtr doc, GnmHtmlTableCtxt *tc)
 			if (buf->len > 0) {
 				GnmCell *cell = sheet_cell_fetch (tc->sheet, col + 1, tc->row);
 				sheet_style_set_pos (tc->sheet, col + 1, tc->row, mstyle);
-				gnm_cell_set_text (cell, buf->str);
+				sheet_cell_set_text (cell, buf->str, NULL);
 			} else
 				gnm_style_unref (mstyle);
 
