@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * dialog-search-replace.c:
@@ -24,18 +23,17 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gnumeric-conf.h>
 #include <gui-util.h>
 #include <search.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 #include <wbc-gtk.h>
 #include <selection.h>
 
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
 #define SEARCH_REPLACE_KEY "search-replace-dialog"
@@ -225,6 +223,9 @@ range_focused (G_GNUC_UNUSED GtkWidget *widget,
 	return FALSE;
 }
 
+/**
+ * dialog_search_replace: (skip)
+ */
 void
 dialog_search_replace (WBCGtk *wbcg,
 		       SearchDialogCallback cb)
@@ -244,7 +245,7 @@ dialog_search_replace (WBCGtk *wbcg,
 	if (gnm_dialog_raise_if_exists (wbcg, SEARCH_REPLACE_KEY))
 		return;
 
-	gui = gnm_gtk_builder_load ("search-replace.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/search-replace.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
@@ -361,7 +362,7 @@ dialog_search_replace_query (WBCGtk *wbcg,
 
 	g_return_val_if_fail (wbcg != NULL, 0);
 
-	gui = gnm_gtk_builder_load ("search-replace.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/search-replace.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return 0;
 
